Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(756)

Unified Diff: webrtc/p2p/base/fakedtlstransport.h

Issue 2679103006: Rename "PacketTransportInterface" to "PacketTransportInternal". (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/p2p/base/dtlstransportinternal.h ('k') | webrtc/p2p/base/fakeicetransport.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/p2p/base/fakedtlstransport.h
diff --git a/webrtc/p2p/base/fakedtlstransport.h b/webrtc/p2p/base/fakedtlstransport.h
index 1fe66ec1b28d2119016d06765327fa6a57ef0d7d..da3537f1fd9ec0f0e76b75e5201c1763d65a666e 100644
--- a/webrtc/p2p/base/fakedtlstransport.h
+++ b/webrtc/p2p/base/fakedtlstransport.h
@@ -182,7 +182,7 @@ class FakeDtlsTransport : public DtlsTransportInternal {
IceTransportInternal* ice_transport() override { return ice_transport_; }
// PacketTransportInterface implementation, which passes through to fake ICE
// transport for sending actual packets.
bool writable() const override { return writable_; }
bool receiving() const override { return receiving_; }
@@ -205,7 +205,7 @@ class FakeDtlsTransport : public DtlsTransportInternal {
int GetError() override { return ice_transport_->GetError(); }
private:
- void OnIceTransportReadPacket(PacketTransportInterface* ice_,
+ void OnIceTransportReadPacket(PacketTransportInternal* ice_,
const char* data,
size_t len,
const rtc::PacketTime& time,
@@ -182,7 +182,7 @@ class FakeDtlsTransport : public DtlsTransportInternal {
IceTransportInternal* ice_transport() override { return ice_transport_; }
- // PacketTransportInterface implementation, which passes through to fake ICE
+ // PacketTransportInternal implementation, which passes through to fake ICE
// transport for sending actual packets.
bool writable() const override { return writable_; }
« no previous file with comments | « webrtc/p2p/base/dtlstransportinternal.h ('k') | webrtc/p2p/base/fakeicetransport.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698